@@ -1,7 +1,7 @@
 """# Workers"""
 
 from flask import current_app, render_template, request
-from sqlalchemy import Boolean, Column, String
+from sqlalchemy import Boolean, Column, Integer, String
 from sqlalchemy.inspection import inspect
 from sqlalchemy_modelid import ModelIdBase
 from sqlalchemy_mutable import MutableType
@@ -14,7 +14,7 @@ def enqueue(enqueue_method):
             # ensure the worker has an id
             session = worker.manager.db.session
             session.add(worker)
-            session.commit()
+            session.flush([worker])
         if not worker.job_in_progress:
             # avoid repeat enqueuing
             job = enqueue_method(worker, *args, **kwargs)
@@ -52,6 +52,11 @@ class WorkerMixin(ModelIdBase):
         Source of the loading image. If `None` the worker will use the 
         manager's loading image.
 
+    ping_interval : int, default=10000
+        The worker will ping the server every `ping_interval` milliseconds to 
+        check the job status. If `None`, the worker will use the manager's 
+        ping interval.
+
     Attributes
     ----------
     callback : str
@@ -81,6 +86,7 @@ class WorkerMixin(ModelIdBase):
     job_id = Column(String)
     template = Column(String)
     loading_img_src = Column(String)
+    ping_interval = Column(Integer)
 
     @property
     def callback(self):
@@ -101,10 +107,14 @@ class WorkerMixin(ModelIdBase):
     def manager(self):
         return current_app.extensions['manager']
 
-    def __init__(self, callback=None, template=None, loading_img_src=None):
+    def __init__(
+            self, callback=None, template=None, loading_img_src=None, 
+            ping_interval=None
+        ):
         self.callback = callback
         self.template = template or self.manager.template
         self.loading_img_src = loading_img_src or self.manager.loading_img_src
+        self.ping_interval = ping_interval or self.manager.ping_interval
         self.reset()
         super().__init__()
 
@@ -141,6 +151,11 @@ class WorkerMixin(ModelIdBase):
         loading_page : str (html)
             The client's loading page.
         """
+        if inspect(model).identity is None:
+            # ensure the model has an identity
+            session = self.manager.db.session
+            session.add(model)
+            session.flush([model])
         return current_app.task_queue.enqueue(
             'flask_worker.tasks.execute_method',
             kwargs=dict(
